==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/CodeDeploy/ListDeploymentConfigs.pm <==

package Paws::CodeDeploy::ListDeploymentConfigs;
  use Moose;
  has NextToken => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'nextToken' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListDeploymentConfigs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::ListDeploymentConfigsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::ListDeploymentConfigs - Arguments for method ListDeploymentConfigs on L<Paws::CodeDeploy>

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListDeploymentConfigs on the
L<AWS CodeDeploy|Paws::CodeDeploy> service. Use the attributes of this class
as arguments to method ListDeploymentConfigs.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListDeploymentConfigs.

=head1 SYNOPSIS

    my $codedeploy = Paws->service('CodeDeploy');
    my $ListDeploymentConfigsOutput = $codedeploy->ListDeploymentConfigs(
      NextToken => 'MyNextToken',    # OPTIONAL
    );

    # Results:
    my $DeploymentConfigsList =
      $ListDeploymentConfigsOutput->DeploymentConfigsList;
    my $NextToken = $ListDeploymentConfigsOutput->NextToken;

    # Returns a L<Paws::CodeDeploy::ListDeploymentConfigsOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codedeploy/ListDeploymentConfigs>

=head1 ATTRIBUTES


=head2 NextToken => Str

An identifier returned from the previous list deployment configurations
call. It can be used to return the next set of deployment
configurations in the list.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListDeploymentConfigs in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/CodeDeploy/ListDeploymentConfigs.pm <==

package Paws::CodeDeploy::ListDeploymentConfigs;
  use Moose;
  has NextToken => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'nextToken' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListDeploymentConfigs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::ListDeploymentConfigsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::ListDeploymentConfigs - Arguments for method ListDeploymentConfigs on L<Paws::CodeDeploy>

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListDeploymentConfigs on the
L<AWS CodeDeploy|Paws::CodeDeploy> service. Use the attributes of this class
as arguments to method ListDeploymentConfigs.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListDeploymentConfigs.

=head1 SYNOPSIS

    my $codedeploy = Paws->service('CodeDeploy');
    my $ListDeploymentConfigsOutput = $codedeploy->ListDeploymentConfigs(
      NextToken => 'MyNextToken',    # OPTIONAL
    );

    # Results:
    my $DeploymentConfigsList =
      $ListDeploymentConfigsOutput->DeploymentConfigsList;
    my $NextToken = $ListDeploymentConfigsOutput->NextToken;

    # Returns a L<Paws::CodeDeploy::ListDeploymentConfigsOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codedeploy/ListDeploymentConfigs>

=head1 ATTRIBUTES


=head2 NextToken => Str

An identifier returned from the previous C<ListDeploymentConfigs> call.
It can be used to return the next set of deployment configurations in
the list.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListDeploymentConfigs in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
